"""Komunikuj się z urządzeniami za pomocą protokołu magistrali I2C."""
from _typeshed import ReadableBuffer
from ..microbit import MicroBitDigitalPin, pin19, pin20
from typing import List

def init(freq: int=100000, sda: MicroBitDigitalPin=pin20, scl: MicroBitDigitalPin=pin19) -> None:
    """Ponownie zainicjuj peryferia.

Example: ``i2c.init()``

:param freq: clock frequency
:param sda: ``sda`` pin (domyślnie 20)
:param scl: ``scl`` pin (domyślnie 19)

On a micro:bit V1 board, changing the I²C pins from defaults will make
the accelerometer and compass stop working, as they are connected
internally to those pins. This warning does not apply to the **V2**
revision of the micro:bit as this has `separate I²C lines <https://tech.microbit.org/hardware/i2c/>`_
for the motion sensors and the edge connector."""
    ...

def scan() -> List[int]:
    """Przeskanuj magistralę w poszukiwaniu urządzeń.

Example: ``i2c.scan()``

:return: A list of 7-bit addresses corresponding to those devices that responded to the scan."""
    ...

def read(addr: int, n: int, repeat: bool=False) -> bytes:
    """Odczytaj bajty z urządzenia..

Example: ``i2c.read(0x50, 64)``

:param addr: 7-bitowy adres urządzenia
:param n: Liczba bajtów do odczytu
:param repeat: Jeśli ``True``, nie zostaną wysłane żadne bity zatrzymania
:return: The bytes read"""
    ...

def write(addr: int, buf: ReadableBuffer, repeat: bool=False) -> None:
    """Zapisz bajty na urządzenie.

Example: ``i2c.write(0x50, bytes([1, 2, 3]))``

:param addr: 7-bitowy adres urządzenia
:param buf: Bufor zawierający bajty do zapisu
:param repeat: Jeśli ``True``, nie zostaną wysłane żadne bity zatrzymania"""
    ...